/*!
 * \file 
 * \brief Lin Click example
 * 
 * # Description
 * The demo application shows communication over uart module.
 *
 * The demo application is composed of two sections :
 * 
 * ## Application Init 
 * UART driver intialization
 * 
 * ## Application Task  
 * Depending on the selected application mode:
 *                       - DEMO_APP_TRANSMITER - Prints "MikroE" message to UART 
 *                       - DEMO_APP_RECEIVER - Reads data from uart and prints to LOG (Default)
 * 
 * 
 * \author Luka Filipovic
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "lin.h"

// ------------------------------------------------------------------ VARIABLES

#define DEMO_APP_RECEIVER
//#define DEMO_APP_TRANSMITER

static lin_t lin;
static log_t logger;

static lin_data_t demo_message[ 9 ] = { 'M', 'i', 'k', 'r', 'o', 'E', 13, 10, 0 };

// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    lin_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    lin_cfg_setup( &cfg );
    LIN_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    lin_init( &lin, &cfg );
}

void application_task ( void )
{
    lin_data_t tmp;
    
    //  Task implementation.
    
#ifdef DEMO_APP_RECEIVER

       // RECEIVER - UART polling

       tmp =  lin_generic_single_read( &lin );
       log_write( &logger, &tmp, LOG_FORMAT_BYTE );
#endif
#ifdef DEMO_APP_TRANSMITER

       // TRANSMITER - TX each 2 sec
       
       lin_generic_multi_write( &lin, demo_message, 9 );
       Delay_ms( 2000 );
#endif

}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
