 

---
# LIN click

The LIN Click is a Click board™ that features the TLE7259-3GE, a LIN transceiver from Infineon Technologies, with integrated wake-up and protection features.

<p align="center">
  <img src="https://download.mikroe.com/images/click_for_ide/lin_click.png" height=300px>
</p>

[click Product page](<https://www.mikroe.com/lin-click>)

---


#### Click library 

- **Author**        : Luka Filipovic
- **Date**          : Nov 2019.
- **Type**          : UART type


# Software Support

We provide a library for the Lin Click 
as well as a demo application (example), developed using MikroElektronika 
[compilers](http://shop.mikroe.com/compilers). 
The demo can run on all the main MikroElektronika [development boards](http://shop.mikroe.com/development-boards).

Package can be downloaded/installed directly form compilers IDE(recommended way), or downloaded from our LibStock, or found on mikroE github account. 

## Library Description

> This library contains API for Lin Click driver.

#### Standard key functions :

- Config Object Initialization function.
> void lin_cfg_setup ( lin_cfg_t *cfg ); 
 
- Initialization function.
> LIN_RETVAL lin_init ( lin_t *ctx, lin_cfg_t *cfg );

- Click Default Configuration function.
> void lin_default_cfg ( lin_t *ctx );


#### Example key functions :

- Generic single read function.
> lin_data_t lin_generic_single_read ( lin_t *ctx );
 
- Generic single write function.
> void lin_generic_single_write ( lin_t *ctx, lin_data_t tx_data );

- Sets state of pin
> uint8_t lin_enable_pin_set( lin_t *ctx, uint8_t state );

## Examples Description

The demo application shows communication over uart module.

**The demo application is composed of two sections :**

### Application Init 

UART driver intialization

```c

void application_init ( void )
{
    log_cfg_t log_cfg;
    lin_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    /log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    lin_cfg_setup( &cfg );
    LIN_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    lin_init( &lin, &cfg );
}
  
```

### Application Task

> Depending on the selected application mode:
>                       - DEMO_APP_TRANSMITER - Prints "MikroE" message to UART 
>                       - DEMO_APP_RECEIVER - Reads data from uart and prints to LOG (Default)

```c

void application_task ( void )
{
    lin_data_t tmp;
    
    //  Task implementation.
    
#ifdef DEMO_APP_RECEIVER

       // RECEIVER - UART polling

       tmp =  lin_generic_single_read( &lin );
       log_write( &logger, &tmp, LOG_FORMAT_BYTE );
#endif
#ifdef DEMO_APP_TRANSMITER

       // TRANSMITER - TX each 2 sec
       
       lin_generic_multi_write( &lin, demo_message, 9 );
       Delay_ms( 2000 );
#endif
}  

```

The full application code, and ready to use projects can be  installed directly form compilers IDE(recommneded) or found on LibStock page or mikroE GitHub accaunt.

**Other mikroE Libraries used in the example:** 

- MikroSDK.Board
- MikroSDK.Log
- Click.Lin

**Additional notes and informations**

Depending on the development board you are using, you may need 
[USB UART click](http://shop.mikroe.com/usb-uart-click), 
[USB UART 2 Click](http://shop.mikroe.com/usb-uart-2-click) or 
[RS232 Click](http://shop.mikroe.com/rs232-click) to connect to your PC, for 
development systems with no UART to USB interface available on the board. The 
terminal available in all Mikroelektronika 
[compilers](http://shop.mikroe.com/compilers), or any other terminal application 
of your choice, can be used to read the message.



---
